============
Installation
============

At the command line::

    $ pip install hydrobm


`pip` will handle all dependencies automatically.
Currently, these include:

- numpy
- pandas
- scipy
- xarray
